@@ -1,10 +1,12 @@
 from .Settings import SettingsSpider
 from .Repo import RepoSpider, TempHandler
 from .ModuleChecker import ModuleCheckerSpider
+from .README import ReadmeSpider
 
 __all__ = [
     "SettingsSpider",
     "RepoSpider",
     "TempHandler",
-    "ModuleCheckerSpider"
+    "ModuleCheckerSpider",
+    "ReadmeSpider"
 ]
