@@ -10,6 +10,7 @@ import urllib.request
 import concurrent.futures
 import importlib
 import scrapy.crawler
+import logging
 
 from .RashScrappers.RashScrappers.spiders import *
 
@@ -17,7 +18,8 @@ __all__ = [
     "JsonHandler",
     "TempHandler",
     "Launcher",
-    "Processes"
+    "Processes",
+    "Setup"
 ]
 
 URL = "https://github.com/RahulARanger/RashSetup"
@@ -41,6 +43,10 @@ class JsonHandler:
     def __str__(self):
         return self.file
 
+    def parse_url(self, raw_link):
+        with urllib.request.urlopen(raw_link) as raw:
+            return self(raw.read())
+
 
 """
 LOCK SAUCE:
@@ -252,96 +258,69 @@ class PluginManager:
         ])
 
 
+class PluginManagerDB:
+    def __init__(self):
+        self.name = "modules.db"
+
+
 class Processes:
-    @staticmethod
-    def pip_install(package, *args):
+    @classmethod
+    def pip_install(cls, package, *args):
         subprocess.run([
-            sys.executable, "-m", 'pip', 'install', package, *args
+            sys.executable, '-m', 'pip', 'install', package, *args
         ])
 
-    @staticmethod
-    def setup_tools(setup_file):
+    @classmethod
+    def setup_tools(cls, setup_file):
         subprocess.run([
             sys.executable, setup_file, "sdist bdist"
         ])
 
-    @staticmethod
-    def pip_uninstall(package):
+    @classmethod
+    def pip_uninstall(cls, package):
         subprocess.run([
-            sys.executable, "-m", "pip", "uninstall", package, "-y"
+            sys.executable, '-m', 'pip', 'uninstall', package, '-y'
         ])
 
-    @staticmethod
-    def rash_process():
-        try:
-            temp = PluginManager()
 
-        except Exception as error:
-            print("Failed to Setup Rash! because of", error)
+class Setup(scrapy.crawler.CrawlerProcess):
+    def __init__(
+            self, pipe, logger: logging.Logger, *modules
+    ):
+        super().__init__()
+        self.pipe = pipe
+        self.logger = logger
+        self.modules = modules
+        self.logger.info("Started Setup")
 
-            while True:
-                pass
+    def grab_settings(self):
+        pass
 
     @classmethod
-    def search(
-            cls,
-            url,
-            result
-    ):
-        collect = []
+    def plant_seed(cls):
+        pass
 
-        file = JsonHandler(os.path.join(
-            os.path.dirname(__file__), "settings.json"
-        ))
+    @classmethod
+    def search_module(cls, pipe, logger, module):
+        handler = Setup(pipe, logger, module)
 
-        def error_pipe(failure):
-            result.put(
-                False
-            )
+        handler.crawl(
+            ModuleCheckerSpider, pipe=pipe, url=module
+        )
 
-            result.put(
-                repr(
-                    failure
-                )
-            )
+        handler.crawl(
+            ReadmeSpider, url=module, pipe=pipe
+        )
 
-        def result_pipe(entity):
-            collect.append(entity)
+        handler.start(True)
 
-        parsed = file.load()
+    @classmethod
+    def download_module(cls, pipe, logger, module):
+        handler = Setup(pipe, logger, module)
 
-        if url in parsed["general"]["modules"].values() or url in parsed["user"]["modules"].values():
-            return error_pipe(
-                "Already Exists"
-            )
-
-        try:
-            process = scrapy.crawler.CrawlerProcess()
-            process.crawl(
-                ModuleCheckerSpider, url=url, pipe=result_pipe, err_back=error_pipe
-            )
-            process.start()
-
-        except Exception as error:
-            return error_pipe(
-                error
-            )
-
-        if collect[-1]:
-
-            result.put(
-                True
-            )
-
-            for _ in collect[: -1]:
-                result.put(
-                    _
-                )
-
-        else:
-            error_pipe(
-                "Wrong format for module!"
-            )
+        handler.crawl(
+            RepoSpider, url=module, pipe=pipe
+        )
 
 
 gc.collect()
